.. sklearn-ann documentation master file, created by
   sphinx-quickstart on Mon Jan  4 10:40:28 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

sklearn-ann
===========

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. include:: ../README.rst
  :start-after: inclusion-marker-do-not-remove


User Guide
---------------------

.. toctree::
   :maxdepth: 2

   background
   kneighbors
   clustering


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
